@@ -24,16 +24,16 @@
 #include <QLineEdit>
 #include <QListView>
 #include <QMenu>
+#include <QPointer>
 #include <QPushButton>
 #include <QScrollBar>
 #include <QStandardItemModel>
 #include <QString>
 
-#include "katemodemanager.h"
-
 namespace KTextEditor
 {
 class DocumentPrivate;
+class Document;
 }
 
 namespace KateModeMenuListData
@@ -44,6 +44,7 @@ class SearchLine;
 class Factory;
 }
 
+class KateFileType;
 /**
  * Class of menu to select the
  * syntax highlighting language (mode menu).
@@ -89,42 +90,10 @@ public:
      */
     enum AutoScroll { ScrollToSelectedItem, ScrollToTop };
 
-    /**
-     * @param searchBarPos Search bar position, can be top or bottom.
-     * @see SearchBarPosition
-     */
-    KateModeMenuList(const SearchBarPosition searchBarPos = Bottom)
-        : QMenu()
-    {
-        init(searchBarPos);
-    }
-    KateModeMenuList(const QString &title, const SearchBarPosition searchBarPos = Bottom)
-        : QMenu(title)
-    {
-        init(searchBarPos);
-    }
-    KateModeMenuList(const QString &title, const SearchBarPosition searchBarPos, QWidget *parent)
-        : QMenu(title, parent)
-    {
-        init(searchBarPos);
-    }
     KateModeMenuList(const QString &title, QWidget *parent)
         : QMenu(title, parent)
     {
-        init(Bottom);
-    }
-    KateModeMenuList(const SearchBarPosition searchBarPos, QWidget *parent)
-        : QMenu(parent)
-    {
-        init(searchBarPos);
-    }
-    KateModeMenuList(QWidget *parent)
-        : QMenu(parent)
-    {
-        init(Bottom);
-    }
-    ~KateModeMenuList()
-    {
+        init();
     }
 
     /**
@@ -165,7 +134,10 @@ public:
      *
      * @see AlignmentHButton, AlignmentVButton, AutoUpdateTextButton
      */
-    void setButton(QPushButton *button, AlignmentHButton positionX = AlignHDefault, AlignmentVButton positionY = AlignTop, AutoUpdateTextButton autoUpdateTextButton = AutoUpdateTextButton(false));
+    void setButton(QPushButton *button,
+                   AlignmentHButton positionX = AlignHDefault,
+                   AlignmentVButton positionY = AlignTop,
+                   AutoUpdateTextButton autoUpdateTextButton = AutoUpdateTextButton(false));
 
     /**
      * Define the scroll when cleaning the search or changing the view.
@@ -195,7 +167,9 @@ protected:
     void showEvent(QShowEvent *event) override;
 
 private:
-    void init(const SearchBarPosition searchBarPos);
+    void init();
+
+    void onAboutToShowMenu();
 
     /**
      * Define the size of the list widget, in pixels. The @p width is also
@@ -287,6 +261,8 @@ private:
 
     QPointer<KTextEditor::DocumentPrivate> m_doc;
 
+    bool m_initialized = false;
+
 private Q_SLOTS:
     /**
      * Action when selecting a item in the list. This also applies
@@ -314,7 +290,7 @@ private:
     }
 
 public:
-    ~ListView()
+    ~ListView() override
     {
     }
 
@@ -397,7 +373,7 @@ private:
     friend Factory;
 
 public:
-    ~ListItem()
+    ~ListItem() override
     {
     }
 
@@ -447,7 +423,7 @@ class SearchLine : public QLineEdit
     Q_OBJECT
 
 public:
-    ~SearchLine()
+    ~SearchLine() override
     {
         m_bestResults.clear();
     }
