@@ -165,7 +165,7 @@ static void registerVariables(KateVariableExpansionManager &mng)
         QStringLiteral("Document:Variable:"),
         i18n("Read a document variable."),
         [](const QStringView &str, KTextEditor::View *view) {
-            return view ? qobject_cast<KTextEditor::DocumentPrivate*>(view->document())->variable(str.mid(18).toString()) : QString();
+            return view ? qobject_cast<KTextEditor::DocumentPrivate *>(view->document())->variable(str.mid(18).toString()) : QString();
         },
         true));
 
@@ -257,8 +257,9 @@ KateVariableExpansionManager::KateVariableExpansionManager(QObject *parent)
 
 bool KateVariableExpansionManager::addVariable(const KTextEditor::Variable &var)
 {
-    if (!var.isValid())
+    if (!var.isValid()) {
         return false;
+    }
 
     // reject duplicates
     const auto alreadyExists = std::any_of(m_variables.begin(), m_variables.end(), [&var](const KTextEditor::Variable &v) {
@@ -269,8 +270,9 @@ bool KateVariableExpansionManager::addVariable(const KTextEditor::Variable &var)
     }
 
     // require a ':' in prefix matches (aka %{JS:1+1})
-    if (var.isPrefixMatch() && !var.name().contains(QLatin1Char(':')))
+    if (var.isPrefixMatch() && !var.name().contains(QLatin1Char(':'))) {
         return false;
+    }
 
     m_variables.push_back(var);
     return true;
@@ -310,7 +312,7 @@ bool KateVariableExpansionManager::expandVariable(const QString &name, KTextEdit
     auto var = variable(name);
     if (!var.isValid()) {
         // try prefix matching
-        for (auto & v : m_variables) {
+        for (auto &v : m_variables) {
             if (v.isPrefixMatch() && name.startsWith(v.name())) {
                 var = v;
                 break;
@@ -326,7 +328,7 @@ bool KateVariableExpansionManager::expandVariable(const QString &name, KTextEdit
     return false;
 }
 
-QString KateVariableExpansionManager::expandText(const QString &text, KTextEditor::View *view) const
+QString KateVariableExpansionManager::expandText(const QString &text, KTextEditor::View *view)
 {
     return KateMacroExpander::expandMacro(text, view);
 }
@@ -378,7 +380,7 @@ void KateVariableExpansionManager::showDialog(const QVector<QWidget *> &widgets,
     }
 
     // add provided variables...
-    for (const auto &var : vars) {
+    for (const auto &var : std::as_const(vars)) {
         if (var.isValid()) {
             dlg->addVariable(var);
         }
